@ECHO OFF
SETLOCAL
TITLE Introscope -- Convert alerts into log lines, starts persistence.
REM This script is called by the Enterprise Manager to convert 
REM alerts to a statement in a log, and starts reporting to a database
REM if not already started.

REM ****
REM Sets the current working directory with quotes around it
REM This enables this file to execute correctly if it is
REM invoked somewhere other than its location.
REM ****
FOR /f "tokens=1 delims=" %%a in ('cd') DO SET PWD=%%a

REM ****
REM Set the command directory to the command argument itself,
REM namely the full path of this file or the relative path
REM to where the file was invoked.
SET CMD_DIR=%0
REM Now simply strip out the name of this file to get dir
REM !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
REM        Use current filename
SET CMD_DIR=%CMD_DIR:alertLevelLogging.cmd=%
REM !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
REM Strip the quotes
REM add quotes if they're not there
SET CMD_DIR="%CMD_DIR%"
REM if not add quotes, then this statement chokes
SET CMD_DIR=%CMD_DIR:"=%
REM if the current dir wasn't determined, just set it to working dir
IF NOT EXIST "%CMD_DIR%" SET CMD_DIR=.
IF "%CMD_DIR%" == %0 SET CMD_DIR=.
IF "%CMD_DIR%" == "%0" SET CMD_DIR=.

REM ****
REM Now set the home directory for Introscope, and others
IF NOT EXIST "%CMD_DIR%\setIscEnv.cmd" goto noSetEnvFile
call "%CMD_DIR%\setIscEnv.cmd"

SET SEMAPHORE=%ISC_LOGS%\tmp\alertLevelLogging.tmp
REM Logging Info
SET LOG_FILE=%ISC_LOGS%\alertReporting.log
SET ERR_FILE=%ISC_LOGS%\alertReporting.err

REM Recording Period (e.g. 10 min ) in secs
REM testing SET REPORTING_PERIOD=1
SET REPORTING_PERIOD=600
REM Set to next hour beyond the minutes above
REM for comparison of semaphore file
SET NEXT_HOUR_BEYOND=1

REM Define matching persistent collections
SET COLLECTIONS=All Alert Conditions
REM Define matching modules
SET MODULES=(.*)


REM Java Options (e.g. increase Max heap size )
SET JAVA_OPTS=-Xms64m -Xmx512m
SET JAVA_OPTS=%JAVA_OPTS% %CLW_USER_OPT% %CLW_PASSWORD_OPT% %CLW_EM_HOST_OPT% %CLW_EM_PORT_OPT%

ECHO %date% %time%: Alert message: %1 >> "%LOG_FILE%"

SET TIME_STR=
FOR /f "tokens=1-4 delims=/ " %%a in ("%date%") DO SET TIME_STR=%%d%%b%%c
FOR /f "tokens=1-4 delims=:." %%a in ("%time%") DO SET TIME_STR=%TIME_STR%%%a

IF EXIST "%SEMAPHORE%" GOTO alreadyRunning
:createSemaphore
ECHO %TIME_STR% > "%SEMAPHORE%"
ECHO %date% %time%: Enabling alert level logging >> "%LOG_FILE%"
"%ISC_JAVA_HOME%\bin\java" %JAVA_OPTS% -jar "%CLW_JAR%" enable persistent collections matching \"%COLLECTIONS%\" in management modules matching \"%MODULES%\" >> "%LOG_FILE%" 2>> "%ERR_FILE%"
"%ISC_BIN%\sleep" %REPORTING_PERIOD%
ECHO %date% %time%: Disabling alert level logging >> "%LOG_FILE%"
"%ISC_JAVA_HOME%\bin\java" %JAVA_OPTS% -jar "%CLW_JAR%" disable persistent collections matching \"%COLLECTIONS%\" in management modules matching \"%MODULES%\" >> "%LOG_FILE%" 2>> "%ERR_FILE%"
del "%SEMAPHORE%"
goto finish

:alreadyRunning
FOR /f "tokens=1" %%a in ('type "%SEMAPHORE%"') DO SET TIME_STR_OLD=%%a
REM example = 2004062111
REM Check that semaphore is not just a lingerer (rare case)
REM do conservative check for greater than 1 hour
SET /a TIME_DIFF=%TIME_STR% - %TIME_STR_OLD%
if /i %TIME_DIFF% GTR %NEXT_HOUR_BEYOND% goto createSemaphore
ECHO %date% %time%: Already running alert level logging >> "%LOG_FILE%"
goto finish

:noSetEnvFile
ECHO There is no environment setup file: setIscEnv.cmd
ECHO Please re-run configureWily.cmd in installation directory!
goto finish

:finish
ENDLOCAL
